startapp
==================================================
**Module**: :mod:`espressodb.management.management.commands.startapp`


.. automodule:: espressodb.management.management.commands.startapp
    :members:
    :special-members:
    :exclude-members: handle
